#
# This file is part of pysnmp software.
#
# Copyright (c) 2005-2017, Ilya Etingof <etingof@gmail.com>
# License: http://pysnmp.sf.net/license.html
#
# PySNMP MIB module SNMP-USER-BASED-SM-MIB (http://pysnmp.sf.net)
# ASN.1 source file:///usr/share/snmp/mibs/SNMP-USER-BASED-SM-MIB.txt
# Produced by pysmi-0.0.5 at Sat Sep 19 23:10:57 2015
# On host grommit.local platform Darwin version 14.4.0 by user ilya
# Using Python version 2.7.6 (default, Sep  9 2014, 15:04:36) 
#
(Integer, ObjectIdentifier, OctetString,) = mibBuilder.importSymbols("ASN1", "Integer", "ObjectIdentifier",
                                                                     "OctetString")
(NamedValues,) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
(ConstraintsUnion, SingleValueConstraint, ConstraintsIntersection, ValueSizeConstraint,
 ValueRangeConstraint,) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ConstraintsUnion", "SingleValueConstraint",
                                                   "ConstraintsIntersection", "ValueSizeConstraint",
                                                   "ValueRangeConstraint")
(SnmpAdminString, snmpPrivProtocols, snmpAuthProtocols, SnmpEngineID,) = mibBuilder.importSymbols("SNMP-FRAMEWORK-MIB",
                                                                                                  "SnmpAdminString",
                                                                                                  "snmpPrivProtocols",
                                                                                                  "snmpAuthProtocols",
                                                                                                  "SnmpEngineID")
(NotificationGroup, ModuleCompliance, ObjectGroup,) = mibBuilder.importSymbols("SNMPv2-CONF", "NotificationGroup",
                                                                               "ModuleCompliance", "ObjectGroup")
(Integer32, MibScalar, MibTable, MibTableRow, MibTableColumn, NotificationType, MibIdentifier, IpAddress, TimeTicks,
 Counter64, Unsigned32, ModuleIdentity, Gauge32, snmpModules, iso, ObjectIdentity, Bits,
 Counter32,) = mibBuilder.importSymbols("SNMPv2-SMI", "Integer32", "MibScalar", "MibTable", "MibTableRow",
                                        "MibTableColumn", "NotificationType", "MibIdentifier", "IpAddress", "TimeTicks",
                                        "Counter64", "Unsigned32", "ModuleIdentity", "Gauge32", "snmpModules", "iso",
                                        "ObjectIdentity", "Bits", "Counter32")
(TextualConvention, AutonomousType, StorageType, TestAndIncr, RowStatus, DisplayString,
 RowPointer,) = mibBuilder.importSymbols("SNMPv2-TC", "TextualConvention", "AutonomousType", "StorageType",
                                         "TestAndIncr", "RowStatus", "DisplayString", "RowPointer")
snmpUsmMIB = ModuleIdentity((1, 3, 6, 1, 6, 3, 15)).setRevisions(
    ("2002-10-16 00:00", "1999-01-20 00:00", "1997-11-20 00:00",))
if mibBuilder.loadTexts:
    snmpUsmMIB.setLastUpdated('200210160000Z')
if mibBuilder.loadTexts:
    snmpUsmMIB.setOrganization('SNMPv3 Working Group')
if mibBuilder.loadTexts:
    snmpUsmMIB.setContactInfo(
        'WG-email:   snmpv3@lists.tislabs.com\n                  Subscribe:  majordomo@lists.tislabs.com\n                              In msg body:  subscribe snmpv3\n\n                  Chair:      Russ Mundy\n                              Network Associates Laboratories\n                  postal:     15204 Omega Drive, Suite 300\n                              Rockville, MD 20850-4601\n                              USA\n                  email:      mundy@tislabs.com\n\n                  phone:      +1 301-947-7107\n\n                  Co-Chair:   David Harrington\n                              Enterasys Networks\n                  Postal:     35 Industrial Way\n                              P. O. Box 5004\n                              Rochester, New Hampshire 03866-5005\n                              USA\n                  EMail:      dbh@enterasys.com\n                  Phone:      +1 603-337-2614\n\n                  Co-editor   Uri Blumenthal\n                              Lucent Technologies\n                  postal:     67 Whippany Rd.\n                              Whippany, NJ 07981\n                              USA\n                  email:      uri@lucent.com\n                  phone:      +1-973-386-2163\n\n                  Co-editor:  Bert Wijnen\n                              Lucent Technologies\n                  postal:     Schagen 33\n                              3461 GL Linschoten\n                              Netherlands\n                  email:      bwijnen@lucent.com\n                  phone:      +31-348-480-685\n                 ')
if mibBuilder.loadTexts:
    snmpUsmMIB.setDescription(
        'The management information definitions for the\n                  SNMP User-based Security Model.\n\n                  Copyright (C) The Internet Society (2002). This\n                  version of this MIB module is part of RFC 3414;\n                  see the RFC itself for full legal notices.\n                 ')
usmMIBObjects = MibIdentifier((1, 3, 6, 1, 6, 3, 15, 1))
usmMIBConformance = MibIdentifier((1, 3, 6, 1, 6, 3, 15, 2))
usmNoAuthProtocol = ObjectIdentity((1, 3, 6, 1, 6, 3, 10, 1, 1, 1))
if mibBuilder.loadTexts:
    usmNoAuthProtocol.setDescription('No Authentication Protocol.')
usmHMACMD5AuthProtocol = ObjectIdentity((1, 3, 6, 1, 6, 3, 10, 1, 1, 2))
if mibBuilder.loadTexts:
    usmHMACMD5AuthProtocol.setDescription('The HMAC-MD5-96 Digest Authentication Protocol.')
usmHMACSHAAuthProtocol = ObjectIdentity((1, 3, 6, 1, 6, 3, 10, 1, 1, 3))
if mibBuilder.loadTexts:
    usmHMACSHAAuthProtocol.setDescription('The HMAC-SHA-96 Digest Authentication Protocol.')
usmNoPrivProtocol = ObjectIdentity((1, 3, 6, 1, 6, 3, 10, 1, 2, 1))
if mibBuilder.loadTexts:
    usmNoPrivProtocol.setDescription('No Privacy Protocol.')
usmDESPrivProtocol = ObjectIdentity((1, 3, 6, 1, 6, 3, 10, 1, 2, 2))
if mibBuilder.loadTexts:
    usmDESPrivProtocol.setDescription('The CBC-DES Symmetric Encryption Protocol.')


class KeyChange(OctetString, TextualConvention):
    pass


usmStats = MibIdentifier((1, 3, 6, 1, 6, 3, 15, 1, 1))
usmStatsUnsupportedSecLevels = MibScalar((1, 3, 6, 1, 6, 3, 15, 1, 1, 1), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts:
    usmStatsUnsupportedSecLevels.setDescription(
        'The total number of packets received by the SNMP\n                 engine which were dropped because they requested a\n                 securityLevel that was unknown to the SNMP engine\n                 or otherwise unavailable.\n                ')
usmStatsNotInTimeWindows = MibScalar((1, 3, 6, 1, 6, 3, 15, 1, 1, 2), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts:
    usmStatsNotInTimeWindows.setDescription(
        "The total number of packets received by the SNMP\n                 engine which were dropped because they appeared\n                 outside of the authoritative SNMP engine's window.\n                ")
usmStatsUnknownUserNames = MibScalar((1, 3, 6, 1, 6, 3, 15, 1, 1, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts:
    usmStatsUnknownUserNames.setDescription(
        'The total number of packets received by the SNMP\n                 engine which were dropped because they referenced a\n                 user that was not known to the SNMP engine.\n                ')
usmStatsUnknownEngineIDs = MibScalar((1, 3, 6, 1, 6, 3, 15, 1, 1, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts:
    usmStatsUnknownEngineIDs.setDescription(
        'The total number of packets received by the SNMP\n                 engine which were dropped because they referenced an\n                 snmpEngineID that was not known to the SNMP engine.\n                ')
usmStatsWrongDigests = MibScalar((1, 3, 6, 1, 6, 3, 15, 1, 1, 5), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts:
    usmStatsWrongDigests.setDescription(
        "The total number of packets received by the SNMP\n                 engine which were dropped because they didn't\n                 contain the expected digest value.\n                ")
usmStatsDecryptionErrors = MibScalar((1, 3, 6, 1, 6, 3, 15, 1, 1, 6), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts:
    usmStatsDecryptionErrors.setDescription(
        'The total number of packets received by the SNMP\n                 engine which were dropped because they could not be\n                 decrypted.\n                ')
usmUser = MibIdentifier((1, 3, 6, 1, 6, 3, 15, 1, 2))
usmUserSpinLock = MibScalar((1, 3, 6, 1, 6, 3, 15, 1, 2, 1), TestAndIncr()).setMaxAccess("readwrite")
if mibBuilder.loadTexts:
    usmUserSpinLock.setDescription(
        'An advisory lock used to allow several cooperating\n                 Command Generator Applications to coordinate their\n                 use of facilities to alter secrets in the\n                 usmUserTable.\n                ')
usmUserTable = MibTable((1, 3, 6, 1, 6, 3, 15, 1, 2, 2), )
if mibBuilder.loadTexts:
    usmUserTable.setDescription(
        "The table of users configured in the SNMP engine's\n                 Local Configuration Datastore (LCD).\n\n                 To create a new user (i.e., to instantiate a new\n                 conceptual row in this table), it is recommended to\n                 follow this procedure:\n\n                   1)  GET(usmUserSpinLock.0) and save in sValue.\n\n                   2)  SET(usmUserSpinLock.0=sValue,\n                           usmUserCloneFrom=templateUser,\n                           usmUserStatus=createAndWait)\n                       You should use a template user to clone from\n                       which has the proper auth/priv protocol defined.\n\n                 If the new user is to use privacy:\n\n                   3)  generate the keyChange value based on the secret\n                       privKey of the clone-from user and the secret key\n                       to be used for the new user. Let us call this\n                       pkcValue.\n                   4)  GET(usmUserSpinLock.0) and save in sValue.\n                   5)  SET(usmUserSpinLock.0=sValue,\n                           usmUserPrivKeyChange=pkcValue\n                           usmUserPublic=randomValue1)\n                   6)  GET(usmUserPulic) and check it has randomValue1.\n                       If not, repeat steps 4-6.\n\n                 If the new user will never use privacy:\n\n                   7)  SET(usmUserPrivProtocol=usmNoPrivProtocol)\n\n                 If the new user is to use authentication:\n\n                   8)  generate the keyChange value based on the secret\n                       authKey of the clone-from user and the secret key\n                       to be used for the new user. Let us call this\n                       akcValue.\n                   9)  GET(usmUserSpinLock.0) and save in sValue.\n                   10) SET(usmUserSpinLock.0=sValue,\n                           usmUserAuthKeyChange=akcValue\n                           usmUserPublic=randomValue2)\n                   11) GET(usmUserPulic) and check it has randomValue2.\n                       If not, repeat steps 9-11.\n\n                 If the new user will never use authentication:\n\n                   12) SET(usmUserAuthProtocol=usmNoAuthProtocol)\n\n                 Finally, activate the new user:\n\n                   13) SET(usmUserStatus=active)\n\n                 The new user should now be available and ready to be\n                 used for SNMPv3 communication. Note however that access\n                 to MIB data must be provided via configuration of the\n                 SNMP-VIEW-BASED-ACM-MIB.\n\n                 The use of usmUserSpinlock is to avoid conflicts with\n                 another SNMP command generator application which may\n                 also be acting on the usmUserTable.\n                ")
usmUserEntry = MibTableRow((1, 3, 6, 1, 6, 3, 15, 1, 2, 2, 1), ).setIndexNames(
    (0, "SNMP-USER-BASED-SM-MIB", "usmUserEngineID"), (0, "SNMP-USER-BASED-SM-MIB", "usmUserName"))
if mibBuilder.loadTexts:
    usmUserEntry.setDescription(
        "A user configured in the SNMP engine's Local\n                 Configuration Datastore (LCD) for the User-based\n                 Security Model.\n                ")
usmUserEngineID = MibTableColumn((1, 3, 6, 1, 6, 3, 15, 1, 2, 2, 1, 1), SnmpEngineID())
if mibBuilder.loadTexts:
    usmUserEngineID.setDescription(
        "An SNMP engine's administratively-unique identifier.\n\n                 In a simple agent, this value is always that agent's\n                 own snmpEngineID value.\n\n                 The value can also take the value of the snmpEngineID\n                 of a remote SNMP engine with which this user can\n                 communicate.\n                ")
usmUserName = MibTableColumn((1, 3, 6, 1, 6, 3, 15, 1, 2, 2, 1, 2),
                             SnmpAdminString().subtype(subtypeSpec=ValueSizeConstraint(1, 32)))
if mibBuilder.loadTexts:
    usmUserName.setDescription(
        'A human readable string representing the name of\n                 the user.\n\n                 This is the (User-based Security) Model dependent\n                 security ID.\n                ')
usmUserSecurityName = MibTableColumn((1, 3, 6, 1, 6, 3, 15, 1, 2, 2, 1, 3), SnmpAdminString()).setMaxAccess("readonly")
if mibBuilder.loadTexts:
    usmUserSecurityName.setDescription(
        'A human readable string representing the user in\n                 Security Model independent format.\n\n                 The default transformation of the User-based Security\n                 Model dependent security ID to the securityName and\n                 vice versa is the identity function so that the\n                 securityName is the same as the userName.\n                ')
usmUserCloneFrom = MibTableColumn((1, 3, 6, 1, 6, 3, 15, 1, 2, 2, 1, 4), RowPointer()).setMaxAccess("readcreate")
if mibBuilder.loadTexts:
    usmUserCloneFrom.setDescription(
        "A pointer to another conceptual row in this\n                 usmUserTable.  The user in this other conceptual\n                 row is called the clone-from user.\n\n                 When a new user is created (i.e., a new conceptual\n                 row is instantiated in this table), the privacy and\n                 authentication parameters of the new user must be\n                 cloned from its clone-from user. These parameters are:\n                   - authentication protocol (usmUserAuthProtocol)\n                   - privacy protocol (usmUserPrivProtocol)\n                 They will be copied regardless of what the current\n                 value is.\n\n                 Cloning also causes the initial values of the secret\n                 authentication key (authKey) and the secret encryption\n\n                 key (privKey) of the new user to be set to the same\n                 values as the corresponding secrets of the clone-from\n                 user to allow the KeyChange process to occur as\n                 required during user creation.\n\n                 The first time an instance of this object is set by\n                 a management operation (either at or after its\n                 instantiation), the cloning process is invoked.\n                 Subsequent writes are successful but invoke no\n                 action to be taken by the receiver.\n                 The cloning process fails with an 'inconsistentName'\n                 error if the conceptual row representing the\n                 clone-from user does not exist or is not in an active\n                 state when the cloning process is invoked.\n\n                 When this object is read, the ZeroDotZero OID\n                 is returned.\n                ")
usmUserAuthProtocol = MibTableColumn((1, 3, 6, 1, 6, 3, 15, 1, 2, 2, 1, 5),
                                     AutonomousType().clone((1, 3, 6, 1, 6, 3, 10, 1, 1, 1))).setMaxAccess("readcreate")
if mibBuilder.loadTexts:
    usmUserAuthProtocol.setDescription(
        "An indication of whether messages sent on behalf of\n                 this user to/from the SNMP engine identified by\n                 usmUserEngineID, can be authenticated, and if so,\n                 the type of authentication protocol which is used.\n\n                 An instance of this object is created concurrently\n                 with the creation of any other object instance for\n                 the same user (i.e., as part of the processing of\n                 the set operation which creates the first object\n                 instance in the same conceptual row).\n\n                 If an initial set operation (i.e. at row creation time)\n                 tries to set a value for an unknown or unsupported\n                 protocol, then a 'wrongValue' error must be returned.\n\n                 The value will be overwritten/set when a set operation\n                 is performed on the corresponding instance of\n                 usmUserCloneFrom.\n\n                 Once instantiated, the value of such an instance of\n                 this object can only be changed via a set operation to\n                 the value of the usmNoAuthProtocol.\n\n                 If a set operation tries to change the value of an\n\n                 existing instance of this object to any value other\n                 than usmNoAuthProtocol, then an 'inconsistentValue'\n                 error must be returned.\n\n                 If a set operation tries to set the value to the\n                 usmNoAuthProtocol while the usmUserPrivProtocol value\n                 in the same row is not equal to usmNoPrivProtocol,\n                 then an 'inconsistentValue' error must be returned.\n                 That means that an SNMP command generator application\n                 must first ensure that the usmUserPrivProtocol is set\n                 to the usmNoPrivProtocol value before it can set\n                 the usmUserAuthProtocol value to usmNoAuthProtocol.\n                ")
usmUserAuthKeyChange = MibTableColumn((1, 3, 6, 1, 6, 3, 15, 1, 2, 2, 1, 6),
                                      KeyChange().clone(hexValue="")).setMaxAccess("readcreate")
if mibBuilder.loadTexts:
    usmUserAuthKeyChange.setDescription(
        "An object, which when modified, causes the secret\n                 authentication key used for messages sent on behalf\n                 of this user to/from the SNMP engine identified by\n                 usmUserEngineID, to be modified via a one-way\n                 function.\n\n                 The associated protocol is the usmUserAuthProtocol.\n                 The associated secret key is the user's secret\n                 authentication key (authKey). The associated hash\n                 algorithm is the algorithm used by the user's\n                 usmUserAuthProtocol.\n\n                 When creating a new user, it is an 'inconsistentName'\n                 error for a set operation to refer to this object\n                 unless it is previously or concurrently initialized\n                 through a set operation on the corresponding instance\n                 of usmUserCloneFrom.\n\n                 When the value of the corresponding usmUserAuthProtocol\n                 is usmNoAuthProtocol, then a set is successful, but\n                 effectively is a no-op.\n\n                 When this object is read, the zero-length (empty)\n                 string is returned.\n\n                 The recommended way to do a key change is as follows:\n\n                   1) GET(usmUserSpinLock.0) and save in sValue.\n                   2) generate the keyChange value based on the old\n                      (existing) secret key and the new secret key,\n                      let us call this kcValue.\n\n                 If you do the key change on behalf of another user:\n\n                   3) SET(usmUserSpinLock.0=sValue,\n                          usmUserAuthKeyChange=kcValue\n                          usmUserPublic=randomValue)\n\n                 If you do the key change for yourself:\n\n                   4) SET(usmUserSpinLock.0=sValue,\n                          usmUserOwnAuthKeyChange=kcValue\n                          usmUserPublic=randomValue)\n\n                 If you get a response with error-status of noError,\n                 then the SET succeeded and the new key is active.\n                 If you do not get a response, then you can issue a\n                 GET(usmUserPublic) and check if the value is equal\n                 to the randomValue you did send in the SET. If so, then\n                 the key change succeeded and the new key is active\n                 (probably the response got lost). If not, then the SET\n                 request probably never reached the target and so you\n                 can start over with the procedure above.\n                ")
usmUserOwnAuthKeyChange = MibTableColumn((1, 3, 6, 1, 6, 3, 15, 1, 2, 2, 1, 7),
                                         KeyChange().clone(hexValue="")).setMaxAccess("readcreate")
if mibBuilder.loadTexts:
    usmUserOwnAuthKeyChange.setDescription(
        "Behaves exactly as usmUserAuthKeyChange, with one\n                 notable difference: in order for the set operation\n                 to succeed, the usmUserName of the operation\n                 requester must match the usmUserName that\n                 indexes the row which is targeted by this\n                 operation.\n                 In addition, the USM security model must be\n                 used for this operation.\n\n                 The idea here is that access to this column can be\n                 public, since it will only allow a user to change\n                 his own secret authentication key (authKey).\n                 Note that this can only be done once the row is active.\n\n                 When a set is received and the usmUserName of the\n                 requester is not the same as the umsUserName that\n                 indexes the row which is targeted by this operation,\n                 then a 'noAccess' error must be returned.\n\n                 When a set is received and the security model in use\n                 is not USM, then a 'noAccess' error must be returned.\n                ")
usmUserPrivProtocol = MibTableColumn((1, 3, 6, 1, 6, 3, 15, 1, 2, 2, 1, 8),
                                     AutonomousType().clone((1, 3, 6, 1, 6, 3, 10, 1, 2, 1))).setMaxAccess("readcreate")
if mibBuilder.loadTexts:
    usmUserPrivProtocol.setDescription(
        "An indication of whether messages sent on behalf of\n                 this user to/from the SNMP engine identified by\n                 usmUserEngineID, can be protected from disclosure,\n                 and if so, the type of privacy protocol which is used.\n\n                 An instance of this object is created concurrently\n                 with the creation of any other object instance for\n                 the same user (i.e., as part of the processing of\n                 the set operation which creates the first object\n                 instance in the same conceptual row).\n\n                 If an initial set operation (i.e. at row creation time)\n                 tries to set a value for an unknown or unsupported\n                 protocol, then a 'wrongValue' error must be returned.\n\n                 The value will be overwritten/set when a set operation\n                 is performed on the corresponding instance of\n                 usmUserCloneFrom.\n\n                 Once instantiated, the value of such an instance of\n                 this object can only be changed via a set operation to\n                 the value of the usmNoPrivProtocol.\n\n                 If a set operation tries to change the value of an\n                 existing instance of this object to any value other\n                 than usmNoPrivProtocol, then an 'inconsistentValue'\n                 error must be returned.\n\n                 Note that if any privacy protocol is used, then you\n                 must also use an authentication protocol. In other\n                 words, if usmUserPrivProtocol is set to anything else\n                 than usmNoPrivProtocol, then the corresponding instance\n                 of usmUserAuthProtocol cannot have a value of\n\n                 usmNoAuthProtocol. If it does, then an\n                 'inconsistentValue' error must be returned.\n                ")
usmUserPrivKeyChange = MibTableColumn((1, 3, 6, 1, 6, 3, 15, 1, 2, 2, 1, 9),
                                      KeyChange().clone(hexValue="")).setMaxAccess("readcreate")
if mibBuilder.loadTexts:
    usmUserPrivKeyChange.setDescription(
        "An object, which when modified, causes the secret\n                 encryption key used for messages sent on behalf\n                 of this user to/from the SNMP engine identified by\n                 usmUserEngineID, to be modified via a one-way\n                 function.\n\n                 The associated protocol is the usmUserPrivProtocol.\n                 The associated secret key is the user's secret\n                 privacy key (privKey). The associated hash\n                 algorithm is the algorithm used by the user's\n                 usmUserAuthProtocol.\n\n                 When creating a new user, it is an 'inconsistentName'\n                 error for a set operation to refer to this object\n                 unless it is previously or concurrently initialized\n                 through a set operation on the corresponding instance\n                 of usmUserCloneFrom.\n\n                 When the value of the corresponding usmUserPrivProtocol\n                 is usmNoPrivProtocol, then a set is successful, but\n                 effectively is a no-op.\n\n                 When this object is read, the zero-length (empty)\n                 string is returned.\n                 See the description clause of usmUserAuthKeyChange for\n                 a recommended procedure to do a key change.\n                ")
usmUserOwnPrivKeyChange = MibTableColumn((1, 3, 6, 1, 6, 3, 15, 1, 2, 2, 1, 10),
                                         KeyChange().clone(hexValue="")).setMaxAccess("readcreate")
if mibBuilder.loadTexts:
    usmUserOwnPrivKeyChange.setDescription(
        "Behaves exactly as usmUserPrivKeyChange, with one\n                 notable difference: in order for the Set operation\n                 to succeed, the usmUserName of the operation\n                 requester must match the usmUserName that indexes\n\n                 the row which is targeted by this operation.\n                 In addition, the USM security model must be\n                 used for this operation.\n\n                 The idea here is that access to this column can be\n                 public, since it will only allow a user to change\n                 his own secret privacy key (privKey).\n                 Note that this can only be done once the row is active.\n\n                 When a set is received and the usmUserName of the\n                 requester is not the same as the umsUserName that\n                 indexes the row which is targeted by this operation,\n                 then a 'noAccess' error must be returned.\n\n                 When a set is received and the security model in use\n                 is not USM, then a 'noAccess' error must be returned.\n                ")
usmUserPublic = MibTableColumn((1, 3, 6, 1, 6, 3, 15, 1, 2, 2, 1, 11),
                               OctetString().subtype(subtypeSpec=ValueSizeConstraint(0, 32)).clone(
                                   hexValue="")).setMaxAccess("readcreate")
if mibBuilder.loadTexts:
    usmUserPublic.setDescription(
        "A publicly-readable value which can be written as part\n                 of the procedure for changing a user's secret\n                 authentication and/or privacy key, and later read to\n                 determine whether the change of the secret was\n                 effected.\n                ")
usmUserStorageType = MibTableColumn((1, 3, 6, 1, 6, 3, 15, 1, 2, 2, 1, 12),
                                    StorageType().clone('nonVolatile')).setMaxAccess("readcreate")
if mibBuilder.loadTexts:
    usmUserStorageType.setDescription(
        "The storage type for this conceptual row.\n\n                 Conceptual rows having the value 'permanent' must\n                 allow write-access at a minimum to:\n\n                 - usmUserAuthKeyChange, usmUserOwnAuthKeyChange\n                   and usmUserPublic for a user who employs\n                   authentication, and\n                 - usmUserPrivKeyChange, usmUserOwnPrivKeyChange\n                   and usmUserPublic for a user who employs\n                   privacy.\n\n                 Note that any user who employs authentication or\n                 privacy must allow its secret(s) to be updated and\n                 thus cannot be 'readOnly'.\n\n                 If an initial set operation tries to set the value to\n                 'readOnly' for a user who employs authentication or\n                 privacy, then an 'inconsistentValue' error must be\n                 returned.  Note that if the value has been previously\n                 set (implicit or explicit) to any value, then the rules\n                 as defined in the StorageType Textual Convention apply.\n\n                 It is an implementation issue to decide if a SET for\n                 a readOnly or permanent row is accepted at all. In some\n                 contexts this may make sense, in others it may not. If\n                 a SET for a readOnly or permanent row is not accepted\n                 at all, then a 'wrongValue' error must be returned.\n                ")
usmUserStatus = MibTableColumn((1, 3, 6, 1, 6, 3, 15, 1, 2, 2, 1, 13), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts:
    usmUserStatus.setDescription(
        "The status of this conceptual row.\n\n                 Until instances of all corresponding columns are\n                 appropriately configured, the value of the\n                 corresponding instance of the usmUserStatus column\n                 is 'notReady'.\n\n                 In particular, a newly created row for a user who\n                 employs authentication, cannot be made active until the\n                 corresponding usmUserCloneFrom and usmUserAuthKeyChange\n                 have been set.\n\n                 Further, a newly created row for a user who also\n                 employs privacy, cannot be made active until the\n                 usmUserPrivKeyChange has been set.\n\n                 The RowStatus TC [RFC2579] requires that this\n                 DESCRIPTION clause states under which circumstances\n                 other objects in this row can be modified:\n\n                 The value of this object has no effect on whether\n                 other objects in this conceptual row can be modified,\n                 except for usmUserOwnAuthKeyChange and\n                 usmUserOwnPrivKeyChange. For these 2 objects, the\n\n                 value of usmUserStatus MUST be active.\n                ")
usmMIBCompliances = MibIdentifier((1, 3, 6, 1, 6, 3, 15, 2, 1))
usmMIBGroups = MibIdentifier((1, 3, 6, 1, 6, 3, 15, 2, 2))
usmMIBCompliance = ModuleCompliance((1, 3, 6, 1, 6, 3, 15, 2, 1, 1)).setObjects(
    *(("SNMP-USER-BASED-SM-MIB", "usmMIBBasicGroup"),))
if mibBuilder.loadTexts:
    usmMIBCompliance.setDescription(
        'The compliance statement for SNMP engines which\n                 implement the SNMP-USER-BASED-SM-MIB.\n                ')
usmMIBBasicGroup = ObjectGroup((1, 3, 6, 1, 6, 3, 15, 2, 2, 1)).setObjects(
    *(("SNMP-USER-BASED-SM-MIB", "usmStatsUnsupportedSecLevels"), ("SNMP-USER-BASED-SM-MIB", "usmStatsNotInTimeWindows"),
      ("SNMP-USER-BASED-SM-MIB", "usmStatsUnknownUserNames"), ("SNMP-USER-BASED-SM-MIB", "usmStatsUnknownEngineIDs"),
      ("SNMP-USER-BASED-SM-MIB", "usmStatsWrongDigests"), ("SNMP-USER-BASED-SM-MIB", "usmStatsDecryptionErrors"),
      ("SNMP-USER-BASED-SM-MIB", "usmUserSpinLock"), ("SNMP-USER-BASED-SM-MIB", "usmUserSecurityName"),
      ("SNMP-USER-BASED-SM-MIB", "usmUserCloneFrom"), ("SNMP-USER-BASED-SM-MIB", "usmUserAuthProtocol"),
      ("SNMP-USER-BASED-SM-MIB", "usmUserAuthKeyChange"), ("SNMP-USER-BASED-SM-MIB", "usmUserOwnAuthKeyChange"),
      ("SNMP-USER-BASED-SM-MIB", "usmUserPrivProtocol"), ("SNMP-USER-BASED-SM-MIB", "usmUserPrivKeyChange"),
      ("SNMP-USER-BASED-SM-MIB", "usmUserOwnPrivKeyChange"), ("SNMP-USER-BASED-SM-MIB", "usmUserPublic"),
      ("SNMP-USER-BASED-SM-MIB", "usmUserStorageType"), ("SNMP-USER-BASED-SM-MIB", "usmUserStatus"))
)
if mibBuilder.loadTexts:
    usmMIBBasicGroup.setDescription(
        'A collection of objects providing for configuration\n                 of an SNMP engine which implements the SNMP\n                 User-based Security Model.\n                ')
mibBuilder.exportSymbols("SNMP-USER-BASED-SM-MIB", usmUserOwnPrivKeyChange=usmUserOwnPrivKeyChange, usmUser=usmUser,
                         usmStatsUnsupportedSecLevels=usmStatsUnsupportedSecLevels,
                         usmHMACSHAAuthProtocol=usmHMACSHAAuthProtocol, snmpUsmMIB=snmpUsmMIB,
                         usmMIBConformance=usmMIBConformance, usmUserCloneFrom=usmUserCloneFrom,
                         usmUserSecurityName=usmUserSecurityName, usmUserTable=usmUserTable,
                         usmNoAuthProtocol=usmNoAuthProtocol, usmNoPrivProtocol=usmNoPrivProtocol,
                         usmUserEntry=usmUserEntry, usmUserAuthProtocol=usmUserAuthProtocol,
                         usmUserStatus=usmUserStatus, usmUserEngineID=usmUserEngineID,
                         usmUserAuthKeyChange=usmUserAuthKeyChange, usmDESPrivProtocol=usmDESPrivProtocol,
                         usmUserPrivProtocol=usmUserPrivProtocol, usmUserStorageType=usmUserStorageType,
                         usmUserPublic=usmUserPublic, usmStatsWrongDigests=usmStatsWrongDigests,
                         usmMIBGroups=usmMIBGroups, usmStats=usmStats,
                         usmStatsNotInTimeWindows=usmStatsNotInTimeWindows, PYSNMP_MODULE_ID=snmpUsmMIB,
                         usmMIBCompliance=usmMIBCompliance, usmStatsUnknownUserNames=usmStatsUnknownUserNames,
                         usmStatsUnknownEngineIDs=usmStatsUnknownEngineIDs, usmMIBCompliances=usmMIBCompliances,
                         KeyChange=KeyChange, usmMIBObjects=usmMIBObjects, usmUserName=usmUserName,
                         usmUserOwnAuthKeyChange=usmUserOwnAuthKeyChange, usmHMACMD5AuthProtocol=usmHMACMD5AuthProtocol,
                         usmMIBBasicGroup=usmMIBBasicGroup, usmStatsDecryptionErrors=usmStatsDecryptionErrors,
                         usmUserSpinLock=usmUserSpinLock, usmUserPrivKeyChange=usmUserPrivKeyChange)



#
# This file is part of pysnmp software.
#
# Copyright (c) 2005-2017, Ilya Etingof <etingof@gmail.com>
# License: http://pysnmp.sf.net/license.html
#
# PySNMP MIB module SNMP-FRAMEWORK-MIB (http://pysnmp.sf.net)
# ASN.1 source file:///usr/share/snmp/mibs/SNMP-FRAMEWORK-MIB.txt
# Produced by pysmi-0.0.5 at Sat Sep 19 19:37:28 2015
# On host grommit.local platform Darwin version 14.4.0 by user ilya
# Using Python version 2.7.6 (default, Sep  9 2014, 15:04:36) 
#
import time

(Integer, ObjectIdentifier, OctetString,) = mibBuilder.importSymbols("ASN1", "Integer", "ObjectIdentifier",
                                                                     "OctetString")
(NamedValues,) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
(ConstraintsUnion, SingleValueConstraint, ConstraintsIntersection, ValueSizeConstraint,
 ValueRangeConstraint,) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ConstraintsUnion", "SingleValueConstraint",
                                                   "ConstraintsIntersection", "ValueSizeConstraint",
                                                   "ValueRangeConstraint")
(NotificationGroup, ModuleCompliance, ObjectGroup,) = mibBuilder.importSymbols("SNMPv2-CONF", "NotificationGroup",
                                                                               "ModuleCompliance", "ObjectGroup")
(Integer32, MibScalar, MibTable, MibTableRow, MibTableColumn, NotificationType, MibIdentifier, IpAddress, TimeTicks,
 Counter64, Unsigned32, ModuleIdentity, Gauge32, snmpModules, iso, ObjectIdentity, Bits,
 Counter32,) = mibBuilder.importSymbols("SNMPv2-SMI", "Integer32", "MibScalar", "MibTable", "MibTableRow",
                                        "MibTableColumn", "NotificationType", "MibIdentifier", "IpAddress", "TimeTicks",
                                        "Counter64", "Unsigned32", "ModuleIdentity", "Gauge32", "snmpModules", "iso",
                                        "ObjectIdentity", "Bits", "Counter32")
(DisplayString, TextualConvention,) = mibBuilder.importSymbols("SNMPv2-TC", "DisplayString", "TextualConvention")

try:
    import os
except ImportError:
    pass

snmpFrameworkMIB = ModuleIdentity((1, 3, 6, 1, 6, 3, 10)).setRevisions(
    ("2002-10-14 00:00", "1999-01-19 00:00", "1997-11-20 00:00",))
if mibBuilder.loadTexts:
    snmpFrameworkMIB.setLastUpdated('200210140000Z')
if mibBuilder.loadTexts:
    snmpFrameworkMIB.setOrganization('SNMPv3 Working Group')
if mibBuilder.loadTexts:
    snmpFrameworkMIB.setContactInfo(
        'WG-EMail:   snmpv3@lists.tislabs.com\n                  Subscribe:  snmpv3-request@lists.tislabs.com\n\n                  Co-Chair:   Russ Mundy\n                              Network Associates Laboratories\n                  postal:     15204 Omega Drive, Suite 300\n                              Rockville, MD 20850-4601\n                              USA\n                  EMail:      mundy@tislabs.com\n                  phone:      +1 301-947-7107\n\n                  Co-Chair &\n                  Co-editor:  David Harrington\n                              Enterasys Networks\n                  postal:     35 Industrial Way\n                              P. O. Box 5005\n                              Rochester, New Hampshire 03866-5005\n                              USA\n                  EMail:      dbh@enterasys.com\n                  phone:      +1 603-337-2614\n\n                  Co-editor:  Randy Presuhn\n                              BMC Software, Inc.\n                  postal:     2141 North First Street\n                              San Jose, California 95131\n                              USA\n                  EMail:      randy_presuhn@bmc.com\n                  phone:      +1 408-546-1006\n\n                  Co-editor:  Bert Wijnen\n                              Lucent Technologies\n                  postal:     Schagen 33\n                              3461 GL Linschoten\n                              Netherlands\n\n                  EMail:      bwijnen@lucent.com\n                  phone:      +31 348-680-485\n                    ')
if mibBuilder.loadTexts:
    snmpFrameworkMIB.setDescription(
        'The SNMP Management Architecture MIB\n\n                     Copyright (C) The Internet Society (2002). This\n                     version of this MIB module is part of RFC 3411;\n                     see the RFC itself for full legal notices.\n                    ')


#
# WARNING: some of the classes below are manually implemented
#

class SnmpAdminString(TextualConvention, OctetString):
    displayHint = "255t"
    subtypeSpec = OctetString.subtypeSpec + ValueSizeConstraint(0, 255)
    encoding = 'utf-8'


class SnmpEngineID(TextualConvention, OctetString):
    subtypeSpec = OctetString.subtypeSpec + ValueSizeConstraint(5, 32)
    defaultValue = [128, 0, 79, 184, 5]
    try:
        # Attempt to base engine ID on local system name and properties
        defaultValue += [ord(x) for x in os.uname()[1][:16]]
    except Exception:
        pass
    try:
        # Attempt to base engine ID on PID
        defaultValue += [os.getpid() >> 8 & 0xff, os.getpid() & 0xff]
    except Exception:
        pass
    # add pseudo-random text ID
    defaultValue += [id(defaultValue) >> 8 & 0xff, id(defaultValue) & 0xff]
    defaultValue = OctetString(defaultValue).asOctets()


class SnmpEngineTime(Integer32):
    def clone(self, value=None, tagSet=None, subtypeSpec=None):
        if value is None:
            try:
                value = time.time() - self
            except Exception:
                pass
        return Integer32.clone(self, value, tagSet, subtypeSpec)


class SnmpSecurityModel(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec + ValueRangeConstraint(0, 2147483647)


class SnmpMessageProcessingModel(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec + ValueRangeConstraint(0, 2147483647)


class SnmpSecurityLevel(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec + SingleValueConstraint(1, 2, 3, )
    namedValues = NamedValues(("noAuthNoPriv", 1), ("authNoPriv", 2), ("authPriv", 3), )


snmpFrameworkAdmin = MibIdentifier((1, 3, 6, 1, 6, 3, 10, 1))
snmpFrameworkMIBObjects = MibIdentifier((1, 3, 6, 1, 6, 3, 10, 2))
snmpFrameworkMIBConformance = MibIdentifier((1, 3, 6, 1, 6, 3, 10, 3))
snmpEngine = MibIdentifier((1, 3, 6, 1, 6, 3, 10, 2, 1))
snmpEngineID = MibScalar((1, 3, 6, 1, 6, 3, 10, 2, 1, 1), SnmpEngineID()).setMaxAccess("readonly")
if mibBuilder.loadTexts:
    snmpEngineID.setDescription(
        "An SNMP engine's administratively-unique identifier.\n\n                 This information SHOULD be stored in non-volatile\n                 storage so that it remains constant across\n                 re-initializations of the SNMP engine.\n                ")
snmpEngineBoots = MibScalar((1, 3, 6, 1, 6, 3, 10, 2, 1, 2),
                            Integer32().subtype(subtypeSpec=ValueRangeConstraint(1, 2147483647))).setMaxAccess(
    "readonly")
if mibBuilder.loadTexts:
    snmpEngineBoots.setDescription(
        'The number of times that the SNMP engine has\n                 (re-)initialized itself since snmpEngineID\n                 was last configured.\n                ')
snmpEngineTime = MibScalar((1, 3, 6, 1, 6, 3, 10, 2, 1, 3),
                           SnmpEngineTime().subtype(subtypeSpec=ValueRangeConstraint(0, 2147483647))).setUnits(
    'seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts:
    snmpEngineTime.setDescription(
        "The number of seconds since the value of\n                 the snmpEngineBoots object last changed.\n                 When incrementing this object's value would\n                 cause it to exceed its maximum,\n                 snmpEngineBoots is incremented as if a\n                 re-initialization had occurred, and this\n                 object's value consequently reverts to zero.\n                ")
snmpEngineMaxMessageSize = MibScalar((1, 3, 6, 1, 6, 3, 10, 2, 1, 4), Integer32().subtype(
    subtypeSpec=ValueRangeConstraint(484, 2147483647))).setMaxAccess("readonly")
if mibBuilder.loadTexts:
    snmpEngineMaxMessageSize.setDescription(
        'The maximum length in octets of an SNMP message\n                 which this SNMP engine can send or receive and\n                 process, determined as the minimum of the maximum\n                 message size values supported among all of the\n                 transports available to and supported by the engine.\n                ')
snmpAuthProtocols = ObjectIdentity((1, 3, 6, 1, 6, 3, 10, 1, 1))
if mibBuilder.loadTexts:
    snmpAuthProtocols.setDescription(
        'Registration point for standards-track\n                  authentication protocols used in SNMP Management\n                  Frameworks.\n                 ')
snmpPrivProtocols = ObjectIdentity((1, 3, 6, 1, 6, 3, 10, 1, 2))
if mibBuilder.loadTexts:
    snmpPrivProtocols.setDescription(
        'Registration point for standards-track privacy\n                  protocols used in SNMP Management Frameworks.\n                 ')
snmpFrameworkMIBCompliances = MibIdentifier((1, 3, 6, 1, 6, 3, 10, 3, 1))
snmpFrameworkMIBGroups = MibIdentifier((1, 3, 6, 1, 6, 3, 10, 3, 2))
snmpFrameworkMIBCompliance = ModuleCompliance((1, 3, 6, 1, 6, 3, 10, 3, 1, 1)).setObjects(
    *(("SNMP-FRAMEWORK-MIB", "snmpEngineGroup"),))
if mibBuilder.loadTexts:
    snmpFrameworkMIBCompliance.setDescription(
        'The compliance statement for SNMP engines which\n                 implement the SNMP Management Framework MIB.\n                ')
snmpEngineGroup = ObjectGroup((1, 3, 6, 1, 6, 3, 10, 3, 2, 1)).setObjects(
    *(("SNMP-FRAMEWORK-MIB", "snmpEngineID"), ("SNMP-FRAMEWORK-MIB", "snmpEngineBoots"),
      ("SNMP-FRAMEWORK-MIB", "snmpEngineTime"), ("SNMP-FRAMEWORK-MIB", "snmpEngineMaxMessageSize"))
)
if mibBuilder.loadTexts:
    snmpEngineGroup.setDescription(
        'A collection of objects for identifying and\n                 determining the configuration and current timeliness\n\n                 values of an SNMP engine.\n                ')
mibBuilder.exportSymbols("SNMP-FRAMEWORK-MIB", snmpPrivProtocols=snmpPrivProtocols, snmpEngine=snmpEngine,
                         snmpEngineMaxMessageSize=snmpEngineMaxMessageSize, snmpAuthProtocols=snmpAuthProtocols,
                         PYSNMP_MODULE_ID=snmpFrameworkMIB, snmpFrameworkMIBConformance=snmpFrameworkMIBConformance,
                         snmpEngineGroup=snmpEngineGroup, SnmpAdminString=SnmpAdminString, snmpEngineID=snmpEngineID,
                         snmpFrameworkAdmin=snmpFrameworkAdmin, snmpFrameworkMIBObjects=snmpFrameworkMIBObjects,
                         SnmpSecurityLevel=SnmpSecurityLevel, snmpFrameworkMIBCompliance=snmpFrameworkMIBCompliance,
                         snmpFrameworkMIBGroups=snmpFrameworkMIBGroups, snmpFrameworkMIB=snmpFrameworkMIB,
                         snmpFrameworkMIBCompliances=snmpFrameworkMIBCompliances, SnmpEngineID=SnmpEngineID,
                         snmpEngineBoots=snmpEngineBoots, SnmpSecurityModel=SnmpSecurityModel,
                         SnmpMessageProcessingModel=SnmpMessageProcessingModel, snmpEngineTime=snmpEngineTime)



#
# This file is part of pysnmp software.
#
# Copyright (c) 2005-2017, Ilya Etingof <etingof@gmail.com>
# License: http://pysnmp.sf.net/license.html
#
# PySNMP MIB module TRANSPORT-ADDRESS-MIB (http://pysnmp.sf.net)
# ASN.1 source file:///usr/share/snmp/mibs/TRANSPORT-ADDRESS-MIB.txt
# Produced by pysmi-0.0.5 at Sat Sep 19 23:19:08 2015
# On host grommit.local platform Darwin version 14.4.0 by user ilya
# Using Python version 2.7.6 (default, Sep  9 2014, 15:04:36) 
#

#
# WARNING: some of the classes below are manually implemented
#
from pyasn1.compat.octets import int2oct, oct2int
from pysnmp import error
from pysnmp.carrier import sockfix
import socket

has_ipv6 = socket.has_ipv6

if hasattr(socket, 'inet_ntop') and hasattr(socket, 'inet_pton'):
    inet_ntop = socket.inet_ntop
    inet_pton = socket.inet_pton
else:
    import sys

    if sys.platform != "win32":
        from socket import inet_ntoa, inet_aton

        inet_ntop = lambda x, y: inet_ntoa(y)
        inet_pton = lambda x, y: inet_aton(y)
        has_ipv6 = False
    elif has_ipv6:
        import struct  # The case of old Python at old Windows


        def inet_pton(address_family, ip_string):
            if address_family == socket.AF_INET:
                return inet_aton(ip_string)
            elif address_family != socket.AF_INET6:
                raise socket.error(
                    'Unknown address family %s' % (address_family,)
                )

            groups = ip_string.split(":")
            spaces = groups.count('')

            if '.' in groups[-1]:
                groups[-1:] = ["%x" % x for x in struct.unpack("!HH", inet_aton(groups[-1]))]

            if spaces == 1:
                idx = groups.index('')
                groups[idx:idx + 1] = ['0'] * (8 - len(groups) + 1)
            elif spaces == 2:
                zeros = ['0'] * (8 - len(groups) + 2)
                if ip_string.startswith('::'):
                    groups[:2] = zeros
                elif ip_string.endswith('::'):
                    groups[-2:] = zeros
                else:
                    raise socket.error(
                        'Invalid IPv6 address: "%s"' % (ip_string,)
                    )
            elif spaces == 3:
                if ip_string != '::':
                    raise socket.error(
                        'Invalid IPv6 address: "%s"' % (ip_string,)
                    )
                return '\x00' * 16
            elif spaces > 3:
                raise socket.error(
                    'Invalid IPv6 address: "%s"' % (ip_string,)
                )

            groups = [t for t in [int(t, 16) for t in groups] if t & 0xFFFF == t]

            if len(groups) != 8:
                raise socket.error(
                    'Invalid IPv6 address: "%s"' % (ip_string,)
                )

            return struct.pack('!8H', *groups)


        def inet_ntop(address_family, packed_ip):
            if address_family == socket.AF_INET:
                return inet_ntop(packed_ip)
            elif address_family != socket.AF_INET6:
                raise socket.error(
                    'Unknown address family %s' % (address_family,)
                )

            if len(packed_ip) != 16:
                raise socket.error(
                    'incorrect address length: %s' % len(packed_ip)
                )

            groups = list(struct.unpack('!8H', packed_ip))

            cur_base = best_base = cur_len = best_len = -1

            for idx in range(8):
                if groups[idx]:
                    if cur_base != -1:
                        if best_base == -1 or cur_len > best_len:
                            best_base, best_len = cur_base, cur_len
                        cur_base = -1
                else:
                    if cur_base == -1:
                        cur_base, cur_len = idx, 1
                    else:
                        cur_len += 1

            if cur_base != -1:
                if best_base == -1 or cur_len > best_len:
                    best_base, best_len = cur_base, cur_len

            if best_base != -1 and best_len > 1:
                groups[best_base:best_base + best_len] = [':']

            if groups[0] == ':':
                groups.insert(0, ':')
            if groups[-1] == ':':
                groups.append(':')

            f = lambda x: x != ':' and '%x' % x or ''

            return ':'.join([f(x) for x in groups])


(Integer, ObjectIdentifier, OctetString,) = mibBuilder.importSymbols("ASN1", "Integer", "ObjectIdentifier",
                                                                     "OctetString")
(NamedValues,) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
(ConstraintsUnion, SingleValueConstraint, ConstraintsIntersection, ValueSizeConstraint,
 ValueRangeConstraint,) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ConstraintsUnion", "SingleValueConstraint",
                                                   "ConstraintsIntersection", "ValueSizeConstraint",
                                                   "ValueRangeConstraint")
(NotificationGroup, ModuleCompliance,) = mibBuilder.importSymbols("SNMPv2-CONF", "NotificationGroup",
                                                                  "ModuleCompliance")
(Integer32, MibScalar, MibTable, MibTableRow, MibTableColumn, NotificationType, MibIdentifier, mib_2, IpAddress,
 TimeTicks, Counter64, Unsigned32, iso, Gauge32, ModuleIdentity, ObjectIdentity, Bits,
 Counter32,) = mibBuilder.importSymbols("SNMPv2-SMI", "Integer32", "MibScalar", "MibTable", "MibTableRow",
                                        "MibTableColumn", "NotificationType", "MibIdentifier", "mib-2", "IpAddress",
                                        "TimeTicks", "Counter64", "Unsigned32", "iso", "Gauge32", "ModuleIdentity",
                                        "ObjectIdentity", "Bits", "Counter32")
(DisplayString, TextualConvention,) = mibBuilder.importSymbols("SNMPv2-TC", "DisplayString", "TextualConvention")

transportAddressMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 100)).setRevisions(("2002-11-01 00:00",))
if mibBuilder.loadTexts:
    transportAddressMIB.setLastUpdated('200211010000Z')
if mibBuilder.loadTexts:
    transportAddressMIB.setOrganization('IETF Operations and Management Area')
if mibBuilder.loadTexts:
    transportAddressMIB.setContactInfo(
        'Juergen Schoenwaelder (Editor)\n         TU Braunschweig\n         Bueltenweg 74/75\n         38106 Braunschweig, Germany\n\n         Phone: +49 531 391-3289\n         EMail: schoenw@ibr.cs.tu-bs.de\n\n         Send comments to <mibs@ops.ietf.org>.')
if mibBuilder.loadTexts:
    transportAddressMIB.setDescription(
        'This MIB module provides commonly used transport\n         address definitions.\n\n         Copyright (C) The Internet Society (2002). This version of\n         this MIB module is part of RFC 3419; see the RFC itself for\n         full legal notices.')
transportDomains = MibIdentifier((1, 3, 6, 1, 2, 1, 100, 1))
transportDomainUdpIpv4 = ObjectIdentity((1, 3, 6, 1, 2, 1, 100, 1, 1))
if mibBuilder.loadTexts:
    transportDomainUdpIpv4.setDescription(
        'The UDP over IPv4 transport domain.  The corresponding\n         transport address is of type TransportAddressIPv4 for\n         global IPv4 addresses.')
transportDomainUdpIpv6 = ObjectIdentity((1, 3, 6, 1, 2, 1, 100, 1, 2))
if mibBuilder.loadTexts:
    transportDomainUdpIpv6.setDescription(
        'The UDP over IPv6 transport domain.  The corresponding\n         transport address is of type TransportAddressIPv6 for\n         global IPv6 addresses.')
transportDomainUdpIpv4z = ObjectIdentity((1, 3, 6, 1, 2, 1, 100, 1, 3))
if mibBuilder.loadTexts:
    transportDomainUdpIpv4z.setDescription(
        'The UDP over IPv4 transport domain.  The corresponding\n         transport address is of type TransportAddressIPv4z for\n         scoped IPv4 addresses with a zone index.')
transportDomainUdpIpv6z = ObjectIdentity((1, 3, 6, 1, 2, 1, 100, 1, 4))
if mibBuilder.loadTexts:
    transportDomainUdpIpv6z.setDescription(
        'The UDP over IPv6 transport domain.  The corresponding\n         transport address is of type TransportAddressIPv6z for\n         scoped IPv6 addresses with a zone index.')
transportDomainTcpIpv4 = ObjectIdentity((1, 3, 6, 1, 2, 1, 100, 1, 5))
if mibBuilder.loadTexts:
    transportDomainTcpIpv4.setDescription(
        'The TCP over IPv4 transport domain.  The corresponding\n         transport address is of type TransportAddressIPv4 for\n         global IPv4 addresses.')
transportDomainTcpIpv6 = ObjectIdentity((1, 3, 6, 1, 2, 1, 100, 1, 6))
if mibBuilder.loadTexts:
    transportDomainTcpIpv6.setDescription(
        'The TCP over IPv6 transport domain.  The corresponding\n         transport address is of type TransportAddressIPv6 for\n         global IPv6 addresses.')
transportDomainTcpIpv4z = ObjectIdentity((1, 3, 6, 1, 2, 1, 100, 1, 7))
if mibBuilder.loadTexts:
    transportDomainTcpIpv4z.setDescription(
        'The TCP over IPv4 transport domain.  The corresponding\n         transport address is of type TransportAddressIPv4z for\n         scoped IPv4 addresses with a zone index.')
transportDomainTcpIpv6z = ObjectIdentity((1, 3, 6, 1, 2, 1, 100, 1, 8))
if mibBuilder.loadTexts:
    transportDomainTcpIpv6z.setDescription(
        'The TCP over IPv6 transport domain.  The corresponding\n         transport address is of type TransportAddressIPv6z for\n         scoped IPv6 addresses with a zone index.')
transportDomainSctpIpv4 = ObjectIdentity((1, 3, 6, 1, 2, 1, 100, 1, 9))
if mibBuilder.loadTexts:
    transportDomainSctpIpv4.setDescription(
        'The SCTP over IPv4 transport domain.  The corresponding\n         transport address is of type TransportAddressIPv4 for\n         global IPv4 addresses. This transport domain usually\n         represents the primary address on multihomed SCTP\n         endpoints.')
transportDomainSctpIpv6 = ObjectIdentity((1, 3, 6, 1, 2, 1, 100, 1, 10))
if mibBuilder.loadTexts:
    transportDomainSctpIpv6.setDescription(
        'The SCTP over IPv6 transport domain.  The corresponding\n         transport address is of type TransportAddressIPv6 for\n         global IPv6 addresses. This transport domain usually\n         represents the primary address on multihomed SCTP\n         endpoints.')
transportDomainSctpIpv4z = ObjectIdentity((1, 3, 6, 1, 2, 1, 100, 1, 11))
if mibBuilder.loadTexts:
    transportDomainSctpIpv4z.setDescription(
        'The SCTP over IPv4 transport domain.  The corresponding\n         transport address is of type TransportAddressIPv4z for\n         scoped IPv4 addresses with a zone index. This transport\n         domain usually represents the primary address on\n         multihomed SCTP endpoints.')
transportDomainSctpIpv6z = ObjectIdentity((1, 3, 6, 1, 2, 1, 100, 1, 12))
if mibBuilder.loadTexts:
    transportDomainSctpIpv6z.setDescription(
        'The SCTP over IPv6 transport domain.  The corresponding\n         transport address is of type TransportAddressIPv6z for\n         scoped IPv6 addresses with a zone index. This transport\n         domain usually represents the primary address on\n         multihomed SCTP endpoints.')
transportDomainLocal = ObjectIdentity((1, 3, 6, 1, 2, 1, 100, 1, 13))
if mibBuilder.loadTexts:
    transportDomainLocal.setDescription(
        'The Posix Local IPC transport domain. The corresponding\n         transport address is of type TransportAddressLocal.\n\n         The Posix Local IPC transport domain incorporates the\n         well-known UNIX domain sockets.')
transportDomainUdpDns = ObjectIdentity((1, 3, 6, 1, 2, 1, 100, 1, 14))
if mibBuilder.loadTexts:
    transportDomainUdpDns.setDescription(
        'The UDP transport domain using fully qualified domain\n         names. The corresponding transport address is of type\n         TransportAddressDns.')
transportDomainTcpDns = ObjectIdentity((1, 3, 6, 1, 2, 1, 100, 1, 15))
if mibBuilder.loadTexts:
    transportDomainTcpDns.setDescription(
        'The TCP transport domain using fully qualified domain\n         names. The corresponding transport address is of type\n         TransportAddressDns.')
transportDomainSctpDns = ObjectIdentity((1, 3, 6, 1, 2, 1, 100, 1, 16))
if mibBuilder.loadTexts:
    transportDomainSctpDns.setDescription(
        'The SCTP transport domain using fully qualified domain\n         names. The corresponding transport address is of type\n         TransportAddressDns.')


class TransportDomain(ObjectIdentifier, TextualConvention):
    pass


class TransportAddressType(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec + SingleValueConstraint(0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15,
                                                                16, )
    namedValues = NamedValues(("unknown", 0), ("udpIpv4", 1), ("udpIpv6", 2), ("udpIpv4z", 3), ("udpIpv6z", 4),
                              ("tcpIpv4", 5), ("tcpIpv6", 6), ("tcpIpv4z", 7), ("tcpIpv6z", 8), ("sctpIpv4", 9),
                              ("sctpIpv6", 10), ("sctpIpv4z", 11), ("sctpIpv6z", 12), ("local", 13), ("udpDns", 14),
                              ("tcpDns", 15), ("sctpDns", 16), )


class TransportAddress(OctetString, TextualConvention):
    subtypeSpec = OctetString.subtypeSpec + ValueSizeConstraint(0, 255)


class TransportAddressIPv4(TextualConvention, OctetString):
    displayHint = "1d.1d.1d.1d:2d"
    subtypeSpec = OctetString.subtypeSpec + ValueSizeConstraint(6, 6)
    fixedLength = 6

    def prettyIn(self, value):
        if isinstance(value, tuple):
            # Wild hack -- need to implement TextualConvention.prettyIn
            value = inet_pton(socket.AF_INET, value[0]) + int2oct((value[1] >> 8) & 0xff) + int2oct(value[1] & 0xff)
        return OctetString.prettyIn(self, value)

    # Socket address syntax coercion
    def __asSocketAddress(self):
        if not hasattr(self, '__tuple_value'):
            v = self.asOctets()
            self.__tuple_value = (
                inet_ntop(socket.AF_INET, v[:4]),
                oct2int(v[4]) << 8 | oct2int(v[5]),
            )
        self.__tuple_value

    def __iter__(self):
        return iter(self.__asSocketAddress())


    def __getitem__(self, item):
        return self.__asSocketAddress()[item]


class TransportAddressIPv6(TextualConvention, OctetString):
    displayHint = "0a[2x:2x:2x:2x:2x:2x:2x:2x]0a:2d"
    subtypeSpec = OctetString.subtypeSpec + ValueSizeConstraint(18, 18)
    fixedLength = 18

    def prettyIn(self, value):
        if not has_ipv6:
            raise error.PySnmpError('IPv6 not supported by platform')
        if isinstance(value, tuple):
            value = inet_pton(socket.AF_INET6, value[0]) + int2oct((value[1] >> 8) & 0xff) + int2oct(value[1] & 0xff)
        return OctetString.prettyIn(self, value)

    # Socket address syntax coercion
    def __asSocketAddress(self):
        if not hasattr(self, '__tuple_value'):
            if not has_ipv6:
                raise error.PySnmpError('IPv6 not supported by platform')
            v = self.asOctets()
            self.__tuple_value = (
                inet_ntop(socket.AF_INET6, v[:16]),
                oct2int(v[16]) << 8 | oct2int(v[17]),
                0,  # flowinfo
                0)  # scopeid
        return self.__tuple_value

    def __iter__(self):
        return iter(self.__asSocketAddress())

    def __getitem__(self, item):
        return self.__asSocketAddress()[item]

class TransportAddressIPv4z(OctetString, TextualConvention):
    displayHint = '1d.1d.1d.1d%4d:2d'
    subtypeSpec = OctetString.subtypeSpec + ValueSizeConstraint(10, 10)
    fixedLength = 10


class TransportAddressIPv6z(OctetString, TextualConvention):
    displayHint = '0a[2x:2x:2x:2x:2x:2x:2x:2x%4d]0a:2d'
    subtypeSpec = OctetString.subtypeSpec + ValueSizeConstraint(22, 22)
    fixedLength = 22


class TransportAddressLocal(OctetString, TextualConvention):
    displayHint = '1a'
    subtypeSpec = OctetString.subtypeSpec + ValueSizeConstraint(1, 255)


class TransportAddressDns(OctetString, TextualConvention):
    displayHint = '1a'
    subtypeSpec = OctetString.subtypeSpec + ValueSizeConstraint(1, 255)


mibBuilder.exportSymbols("TRANSPORT-ADDRESS-MIB", transportDomainTcpIpv4=transportDomainTcpIpv4,
                         transportDomainTcpIpv6z=transportDomainTcpIpv6z, transportDomainLocal=transportDomainLocal,
                         transportDomainSctpIpv4=transportDomainSctpIpv4, transportDomainTcpDns=transportDomainTcpDns,
                         TransportAddressIPv6=TransportAddressIPv6, TransportAddressType=TransportAddressType,
                         transportDomains=transportDomains, transportDomainUdpIpv6=transportDomainUdpIpv6,
                         transportDomainUdpIpv6z=transportDomainUdpIpv6z, PYSNMP_MODULE_ID=transportAddressMIB,
                         TransportAddressIPv4=TransportAddressIPv4, transportDomainSctpIpv6z=transportDomainSctpIpv6z,
                         TransportDomain=TransportDomain, transportDomainUdpIpv4=transportDomainUdpIpv4,
                         transportDomainTcpIpv4z=transportDomainTcpIpv4z,
                         transportDomainSctpIpv4z=transportDomainSctpIpv4z,
                         transportDomainSctpIpv6=transportDomainSctpIpv6, TransportAddressDns=TransportAddressDns,
                         TransportAddress=TransportAddress, transportAddressMIB=transportAddressMIB,
                         TransportAddressLocal=TransportAddressLocal, transportDomainUdpIpv4z=transportDomainUdpIpv4z,
                         TransportAddressIPv6z=TransportAddressIPv6z, transportDomainTcpIpv6=transportDomainTcpIpv6,
                         transportDomainUdpDns=transportDomainUdpDns, TransportAddressIPv4z=TransportAddressIPv4z,
                         transportDomainSctpDns=transportDomainSctpDns)



#
# This file is part of pysnmp software.
#
# Copyright (c) 2005-2017, Ilya Etingof <etingof@gmail.com>
# License: http://pysnmp.sf.net/license.html
#
# PySNMP MIB module SNMP-MPD-MIB (http://pysnmp.sf.net)
# ASN.1 source file:///usr/share/snmp/mibs/SNMP-MPD-MIB.txt
# Produced by pysmi-0.0.5 at Sat Sep 19 16:31:46 2015
# On host grommit.local platform Darwin version 14.4.0 by user ilya
# Using Python version 2.7.6 (default, Sep  9 2014, 15:04:36) 
#
(Integer, ObjectIdentifier, OctetString,) = mibBuilder.importSymbols("ASN1", "Integer", "ObjectIdentifier",
                                                                     "OctetString")
(NamedValues,) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
(ConstraintsUnion, SingleValueConstraint, ConstraintsIntersection, ValueSizeConstraint,
 ValueRangeConstraint,) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ConstraintsUnion", "SingleValueConstraint",
                                                   "ConstraintsIntersection", "ValueSizeConstraint",
                                                   "ValueRangeConstraint")
(NotificationGroup, ModuleCompliance, ObjectGroup,) = mibBuilder.importSymbols("SNMPv2-CONF", "NotificationGroup",
                                                                               "ModuleCompliance", "ObjectGroup")
(Integer32, MibScalar, MibTable, MibTableRow, MibTableColumn, NotificationType, MibIdentifier, IpAddress, TimeTicks,
 Counter64, Unsigned32, ModuleIdentity, Gauge32, snmpModules, iso, ObjectIdentity, Bits,
 Counter32,) = mibBuilder.importSymbols("SNMPv2-SMI", "Integer32", "MibScalar", "MibTable", "MibTableRow",
                                        "MibTableColumn", "NotificationType", "MibIdentifier", "IpAddress", "TimeTicks",
                                        "Counter64", "Unsigned32", "ModuleIdentity", "Gauge32", "snmpModules", "iso",
                                        "ObjectIdentity", "Bits", "Counter32")
(DisplayString, TextualConvention,) = mibBuilder.importSymbols("SNMPv2-TC", "DisplayString", "TextualConvention")
snmpMPDMIB = ModuleIdentity((1, 3, 6, 1, 6, 3, 11)).setRevisions(
    ("2002-10-14 00:00", "1999-05-04 16:36", "1997-09-30 00:00",))
if mibBuilder.loadTexts:
    snmpMPDMIB.setLastUpdated('200210140000Z')
if mibBuilder.loadTexts:
    snmpMPDMIB.setOrganization('SNMPv3 Working Group')
if mibBuilder.loadTexts:
    snmpMPDMIB.setContactInfo(
        'WG-EMail:   snmpv3@lists.tislabs.com\n                  Subscribe:  snmpv3-request@lists.tislabs.com\n\n                  Co-Chair:   Russ Mundy\n                              Network Associates Laboratories\n                  postal:     15204 Omega Drive, Suite 300\n                              Rockville, MD 20850-4601\n                              USA\n\n                  EMail:      mundy@tislabs.com\n                  phone:      +1 301-947-7107\n\n                  Co-Chair &\n                  Co-editor:  David Harrington\n                              Enterasys Networks\n                  postal:     35 Industrial Way\n                              P. O. Box 5005\n                              Rochester NH 03866-5005\n                              USA\n                  EMail:      dbh@enterasys.com\n                  phone:      +1 603-337-2614\n\n                  Co-editor:  Jeffrey Case\n                              SNMP Research, Inc.\n                  postal:     3001 Kimberlin Heights Road\n                              Knoxville, TN 37920-9716\n                              USA\n                  EMail:      case@snmp.com\n                  phone:      +1 423-573-1434\n\n                  Co-editor:  Randy Presuhn\n                              BMC Software, Inc.\n                  postal:     2141 North First Street\n                              San Jose, CA 95131\n                              USA\n                  EMail:      randy_presuhn@bmc.com\n                  phone:      +1 408-546-1006\n\n                  Co-editor:  Bert Wijnen\n                              Lucent Technologies\n                  postal:     Schagen 33\n                              3461 GL Linschoten\n                              Netherlands\n                  EMail:      bwijnen@lucent.com\n                  phone:      +31 348-680-485\n                 ')
if mibBuilder.loadTexts:
    snmpMPDMIB.setDescription(
        'The MIB for Message Processing and Dispatching\n\n                  Copyright (C) The Internet Society (2002). This\n                  version of this MIB module is part of RFC 3412;\n                  see the RFC itself for full legal notices.\n                 ')
snmpMPDAdmin = MibIdentifier((1, 3, 6, 1, 6, 3, 11, 1))
snmpMPDMIBObjects = MibIdentifier((1, 3, 6, 1, 6, 3, 11, 2))
snmpMPDMIBConformance = MibIdentifier((1, 3, 6, 1, 6, 3, 11, 3))
snmpMPDStats = MibIdentifier((1, 3, 6, 1, 6, 3, 11, 2, 1))
snmpUnknownSecurityModels = MibScalar((1, 3, 6, 1, 6, 3, 11, 2, 1, 1), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts:
    snmpUnknownSecurityModels.setDescription(
        'The total number of packets received by the SNMP\n                 engine which were dropped because they referenced a\n                 securityModel that was not known to or supported by\n                 the SNMP engine.\n                ')
snmpInvalidMsgs = MibScalar((1, 3, 6, 1, 6, 3, 11, 2, 1, 2), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts:
    snmpInvalidMsgs.setDescription(
        'The total number of packets received by the SNMP\n                 engine which were dropped because there were invalid\n                 or inconsistent components in the SNMP message.\n                ')
snmpUnknownPDUHandlers = MibScalar((1, 3, 6, 1, 6, 3, 11, 2, 1, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts:
    snmpUnknownPDUHandlers.setDescription(
        'The total number of packets received by the SNMP\n                 engine which were dropped because the PDU contained\n                 in the packet could not be passed to an application\n                 responsible for handling the pduType, e.g. no SNMP\n                 application had registered for the proper\n                 combination of the contextEngineID and the pduType.\n                ')
snmpMPDMIBCompliances = MibIdentifier((1, 3, 6, 1, 6, 3, 11, 3, 1))
snmpMPDMIBGroups = MibIdentifier((1, 3, 6, 1, 6, 3, 11, 3, 2))
snmpMPDCompliance = ModuleCompliance((1, 3, 6, 1, 6, 3, 11, 3, 1, 1)).setObjects(*(("SNMP-MPD-MIB", "snmpMPDGroup"),))
if mibBuilder.loadTexts:
    snmpMPDCompliance.setDescription(
        'The compliance statement for SNMP entities which\n                 implement the SNMP-MPD-MIB.\n                ')
snmpMPDGroup = ObjectGroup((1, 3, 6, 1, 6, 3, 11, 3, 2, 1)).setObjects(
    *(("SNMP-MPD-MIB", "snmpUnknownSecurityModels"), ("SNMP-MPD-MIB", "snmpInvalidMsgs"),
      ("SNMP-MPD-MIB", "snmpUnknownPDUHandlers"))
)
if mibBuilder.loadTexts:
    snmpMPDGroup.setDescription(
        'A collection of objects providing for remote\n                 monitoring of the SNMP Message Processing and\n                 Dispatching process.\n                ')
mibBuilder.exportSymbols("SNMP-MPD-MIB", snmpMPDMIBObjects=snmpMPDMIBObjects,
                         snmpMPDMIBCompliances=snmpMPDMIBCompliances, snmpMPDCompliance=snmpMPDCompliance,
                         snmpMPDMIBGroups=snmpMPDMIBGroups, snmpMPDMIB=snmpMPDMIB, snmpMPDAdmin=snmpMPDAdmin,
                         snmpInvalidMsgs=snmpInvalidMsgs, PYSNMP_MODULE_ID=snmpMPDMIB, snmpMPDStats=snmpMPDStats,
                         snmpMPDMIBConformance=snmpMPDMIBConformance,
                         snmpUnknownSecurityModels=snmpUnknownSecurityModels, snmpMPDGroup=snmpMPDGroup,
                         snmpUnknownPDUHandlers=snmpUnknownPDUHandlers)
